import AbstractPolicy from './AbstractPolicy.js';
import ResourceLocator from '../ResourceLocator.js';
import { RemotePolicyInterface } from '../../interfaces/PolicyInterface.js';
import PolicyTypeEnum from '../../enum/PolicyTypeEnum.js';
/**
 * Set remote policy body
 *
 * If the policy type is set to use a Remote Policy, then the Resource Locator object described in Section 3.4.1 is
 * used to describe the remote policy.
 */
declare class RemotePolicy extends AbstractPolicy implements RemotePolicyInterface {
    readonly type: PolicyTypeEnum;
    readonly remotePolicy: ResourceLocator;
    static parse(buff: Uint8Array, useEcdsaBinding: boolean): {
        offset: number;
        policy: RemotePolicy;
    };
    constructor(type: PolicyTypeEnum, binding: Uint8Array, resource: ResourceLocator);
    /**
     * Length of policy
     *
     * @returns { number } length
     */
    getLength(): number;
    /**
     * Return the content of the policy
     */
    toBuffer(): Uint8Array;
}
export default RemotePolicy;
//# sourceMappingURL=RemotePolicy.d.ts.map