import Header from './Header.js';
/**
 * NanoTDF Signature
 *
 * The signature section is an optional section that contains an ECDSA signature used to cryptographically bind the Header and Payload to a creator of the nanotdf. The key used for signing is the private key of the creator of the nanotdf. The ECC Params used for the signature are described in Section 3.3.1.4.2. The private key used for this signature is distinctly different than the ephemeral private key. This is a persistent key belonging to an individual, entity, or device that creates nanotdfs. The signature is used to authenticate the entire nanotdf and contains both the public key related to the creators private key and the resulting signature. The structure of this section:
 *
 * | Section    | Minimum Length (B) | Maximum Length (B) |
 * |------------|--------------------|--------------------|
 * | Public Key | 33                 | 67                 |
 * | Signature  | 64                 | 132                |
 *
 * @link https://github.com/virtru/nanotdf/blob/master/spec/index.md#333-signature
 */
export default class Signature {
    publicKey: Uint8Array;
    signature: Uint8Array;
    static parse(header: Header, buff: Uint8Array): {
        signature: Signature;
        offset: number;
    } | never;
    constructor(publicKey: Uint8Array, signature: Uint8Array);
    /**
     * Length
     *
     * @returns { number } Length of signature
     */
    get length(): number;
    /**
     * Copy the contents of the signature to buffer
     */
    copyToBuffer(target: Uint8Array): void;
}
//# sourceMappingURL=Signature.d.ts.map