import { type AnyKeyPair, type PemKeyPair } from './declarations.js';
/**
 * Validates a specified key size
 * @param size in bits requested
 * @param minSize in bits allowed
 */
export declare const isValidAsymmetricKeySize: (size: number | undefined, minSize?: number) => boolean;
/**
 * Format a base64 string representation of a key file
 * in PEM PKCS#8 format by adding a header and footer
 * and new lines.
 *
 * The PEM spec says to use <CR><LF> (\r\n) per
 * https://tools.ietf.org/html/rfc1421#section-4.3.2.2, but
 * many implementations use just \n, so this function
 * follows the convention over the spec.
 *
 * @param  base64KeyString input
 * @param  label header and footer label that identifies key type
 * @return formatted output
 */
export declare const formatAsPem: (bytes: ArrayBuffer, label: string) => string;
/**
 * Remove PEM formatting (new line characters and headers / footers)
 * from a PEM string
 *
 * @param  input - PEM formatted string
 * @return String with formatting removed
 */
export declare const removePemFormatting: (input: string) => string;
export declare const isPemKeyPair: (i: AnyKeyPair) => i is PemKeyPair;
export declare const isCryptoKeyPair: (i: AnyKeyPair) => i is CryptoKeyPair;
export declare const toCryptoKeyPair: (input: AnyKeyPair) => Promise<CryptoKeyPair>;
//# sourceMappingURL=crypto-utils.d.ts.map